#!/bin/sh

#
# UNIX version of TID patch install script
#
# @(#)58       1.1  src/tim/efix/run_efix.sh, timr1_install, tim_1.1, ECS_20011024B 10/23/01 13:44:08

usage() {
	echo "== Usage:  $0 [ WebSphere_AppServer_path ]"
	quit
}

quit () {
	echo "== Exiting now."
	exit 0
}

get_TID_version() {
	TID_WAR=$WAS_HOME/installedApps/TivoliIdentityDirector.ear/tid.war
	sed 's/^.*= //' $TID_WAR/config/versionInfo
}

if [ $# = 1 ]; then
	WAS_HOME=$1
fi

if [ "$WAS_HOME" = "" ]; then
	echo "== Please enter the WebSphere AppServer directory path (WAS_HOME):"
	read WAS_HOME
fi

if [ "$WAS_HOME" = "" ]; then
	usage;
fi

if [ \! -d $WAS_HOME ]; then
	echo "== \"$WAS_HOME\" is not a valid path for WAS_HOME..."
	quit
fi

## #
## # won't need this logic on unix
## #
## WAS_HOME=`echo $WAS_HOME | sed 's,\\\,\/,g'` 

echo "== Using $WAS_HOME as WAS_HOME..."

#
# Ensure TID is at the right version level for this patch
#
echo "== Inspecting TID version info..."
VERSION=`get_TID_version`
PREREQ_VERSION="1.1"
echo "== Current TID version is <$VERSION>..."
if [ "$VERSION" != "$PREREQ_VERSION" ]; then
	echo "== Cannot install patch TID1 unless TID version is $PREREQ_VERSION; exiting now."
	exit 0
fi

#
# Extract the patch
#
echo "== Extracting the TID1 patch..."
java -jar TID1_PTF_AEsServer.jar -Target $WAS_HOME -Force

#
# Check to be sure that the patch was extracted before doing
# post-install work
#
VERSION=`get_TID_version`
if [ "$VERSION" = "$PREREQ_VERSION" ]; then
	echo "== Patch was not installed; exiting now."
	exit 0
fi

echo "== Performing post-install actions..."

#
# TID1 after-actions
#

# Clobber precompilations for the JSP files we've just replaced
CACHE_DIR=$WAS_HOME/installedApps/TivoliIdentityDirector.ear/tid.war/WEB-INF/classes/secure
rm -f $CACHE_DIR/challenge/*
rm -f $CACHE_DIR/update/*
echo "== TID1 patch installation is complete..."

quit
